Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(185)

Unified Diff: third_party/WebKit/Source/modules/serviceworkers/ServiceWorkerGlobalScopeClient.h

Issue 2034663002: ServiceWorker: Keep the worker alive until FetchEvent.waitUntil settles (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/serviceworkers/ServiceWorkerGlobalScopeClient.h
diff --git a/third_party/WebKit/Source/modules/serviceworkers/ServiceWorkerGlobalScopeClient.h b/third_party/WebKit/Source/modules/serviceworkers/ServiceWorkerGlobalScopeClient.h
index 8040ac1ad47809a61e58329c7f8e9e44f92bf8af..cd9d82b441ec1aba3994115dfe13bb97621a3a43 100644
--- a/third_party/WebKit/Source/modules/serviceworkers/ServiceWorkerGlobalScopeClient.h
+++ b/third_party/WebKit/Source/modules/serviceworkers/ServiceWorkerGlobalScopeClient.h
@@ -71,10 +71,11 @@ public:
virtual void didHandleActivateEvent(int eventID, WebServiceWorkerEventResult) = 0;
virtual void didHandleExtendableMessageEvent(int eventID, WebServiceWorkerEventResult) = 0;
// Calling didHandleFetchEvent without response means no response was
// provided by the service worker in the fetch events, so fallback to native.
- virtual void didHandleFetchEvent(int fetchEventID) = 0;
- virtual void didHandleFetchEvent(int fetchEventID, const WebServiceWorkerResponse&) = 0;
+ virtual void respondToFetchEvent(int responseID) = 0;
+ virtual void respondToFetchEvent(int responseID, const WebServiceWorkerResponse&) = 0;
+ virtual void didHandleFetchEvent(int eventFinishID, WebServiceWorkerEventResult) = 0;
virtual void didHandleInstallEvent(int installEventID, WebServiceWorkerEventResult) = 0;
virtual void didHandleNotificationClickEvent(int eventID, WebServiceWorkerEventResult) = 0;
virtual void didHandleNotificationCloseEvent(int eventID, WebServiceWorkerEventResult) = 0;
@@ -71,10 +71,11 @@ public:
virtual void didHandleActivateEvent(int eventID, WebServiceWorkerEventResult) = 0;
virtual void didHandleExtendableMessageEvent(int eventID, WebServiceWorkerEventResult) = 0;
- // Calling didHandleFetchEvent without response means no response was
+ // Calling respondToFetchEvent without response means no response was
// provided by the service worker in the fetch events, so fallback to native.

Powered by Google App Engine
This is Rietveld 408576698